import React from "react";
import { App, Views } from "@react-fullstack/fullstack";
import SocketIO from "socket.io";
interface Props<ViewsInterface extends Views> {
    /**
     * The port the socket will run on.
     */
    port: number;
    /**
     * The server react app
     */
    children: () => JSX.Element;
    /**
     * Object containing view shared component
     */
    views: ViewsInterface;
    /**
     * share one app across all clients.
     */
    singleInstance?: boolean;
    /**
     * socket.io server options, note: must be passed with the first component mount, updating this prop will have no effect.
     * Note: cors header does not default to "*"
     */
    socketOptions?: Partial<SocketIO.ServerOptions>;
}
interface State<ViewsInterface extends Views> {
    apps: {
        [id: string]: SocketIO.Socket;
    };
}
/**
 * "@react-fullstack/fullstack" socket server
 */
declare class Server<ViewsInterface extends Views> extends React.Component<Props<ViewsInterface>, State<ViewsInterface>> {
    server: SocketIO.Server;
    mainAppRef?: App<ViewsInterface>;
    constructor(props: Props<ViewsInterface>);
    state: State<ViewsInterface>;
    componentDidMount: () => void;
    componentWillUnmount: () => void;
    render: () => JSX.Element;
}
export { Server };
